{ *************************************************************************** }
{ Module Name: DRIVER.PAS                                                     }
{ Purpose: the declaration of functions, data structures, status codes,       }
{         constants, and messages                                             }
{ Version: 3.01                                                               }
{ Date: 04/16/1998                                                            }
{ Copyright (c) 1996 Advantech Corp. Ltd.                                     }
{ All rights reserved.                                                        }
{ *************************************************************************** }
unit Driver;
interface
uses windows;
const
{ ************************************************************************ }
{   Constant Definition                                                    }
{ ************************************************************************ }
  MaxDev             =  255;  {  max. # of devices }
  MaxDevNameLen      =  64;   {  max lenght of device name }
  MaxGroup           =  6;
  MaxPort            =  3;
  MaxErrMsgLen       =  80;
  MAX_DEVICE_NAME_LEN=  64;
  MAX_DRIVER_NAME_LEN=  16;
  MAX_DAUGHTER_NUM   =  16;
  MAX_DIO_PORT       =  48;
  MAX_AO_RANGE       =  16;

  REMOTE             =    1;
  REMOTE1            =    REMOTE+1;      {  For PCL-818L JP7 = 5V }
  REMOTE2            =    REMOTE1+1;     {  For PCL-818L JP7 =10V }
  NONPROG            =    0;
  PROG               =    REMOTE;
  INTERNAL           =    0;
  EXTERNAL           =    1;
  SINGLEENDED        =    0;
  DIFFERENTIAL       =    1;
  BIPOLAR            =    0;
  UNIPOLAR           =    1;
  PORTA              =    0;
  PORTB              =    1;
  PORTC              =    2;
  INPORT             =    0;
  OUTPORT            =    1;

{ ************************************************************************ }
{   Define board vendor ID                                                 }
{ ************************************************************************ }
  AAC      = $0000;                    { Advantech }
  MB       = $1000;                    { Keithley/MetraByte }
  BB       = $2000;                    { Burr Brown }
  GRAYHILL = $3000;                    { Grayhill }
  KGS      = $4000;

{ ************************************************************************ }
{    Define DAS I/O Board ID.                                              }
{ ************************************************************************ }
  NONE         = $00;             { not available }

{ Advantech board ID }
   BD_DEMO      =  AAC Or $00;     {  demo board }
   BD_PCL711    =  AAC Or $01;     {  PCL-711 board }
   BD_PCL812    =  AAC Or $02;     {  PCL-812 board }
   BD_PCL812PG  =  AAC Or $03;     {  PCL-812PG board }
   BD_PCL718    =  AAC Or $04;     {  PCL-718 board }
   BD_PCL818    =  AAC Or $05;     {  PCL-818 board }
   BD_PCL814    =  AAC Or $06;     {  PCL-814 board }
   BD_PCL720    =  AAC Or $07;     {  PCL-722 board }
   BD_PCL722    =  AAC Or $08;     {  PCL-720 board }
   BD_PCL724    =  AAC Or $09;     {  PCL-724 board }
   BD_AD4011    =  AAC Or $0a;     {  ADAM 4011 Module }
   BD_AD4012    =  AAC Or $0b;     {  ADAM 4012 Module }
   BD_AD4013    =  AAC Or $0c;     {  ADAM 4013 Module }
   BD_AD4021    =  AAC Or $0d;     {  ADAM 4021 Module }
   BD_AD4050    =  AAC Or $0e;     {  ADAM 4050 Module }
   BD_AD4060    =  AAC Or $0f;     {  ADAM 4060 Module }
   BD_PCL711B   =  AAC Or $10;     {  PCL-711B }
   BD_PCL818H   =  AAC Or $11;     {  PCL-818H }
   BD_PCL814B   =  AAC Or $12;     {  PCL-814B }
   BD_PCL816    =  AAC Or $13;     {  PCL-816  }
   BD_814_DIO_1 =  AAC Or $14;     {  PCL-816/814B 8255 DIO module   }
   BD_814_DA_1  =  AAC Or $15;     {  PCL-816/814B 12 bit D/A module }
   BD_816_DA_1  =  AAC Or $16;     {  PCL-816/814B 16 bit D/A module }
   BD_PCL830    =  AAC Or $17;     {  PCL-830 9513A Counter Card }
   BD_PCL726    =  AAC Or $18;     {  PCL-726 D/A card }
   BD_PCL727    =  AAC Or $19;     {  PCL-727 D/A card }
   BD_PCL728    =  AAC Or $1a;     {  PCL-728 D/A card }
   BD_AD4052    =  AAC Or $1b;     {  ADAM 4052 Module }
   BD_AD4014D   =  AAC Or $1c;     {  ADAM 4014D Module }
   BD_AD4017    =  AAC Or $1d;     {  ADAM 4017 Module  }
   BD_AD4080D   =  AAC Or $1e;     {  ADAM 4080D Module }
   BD_PCL721    =  AAC Or $1f;     {  PCL-721 32-bit Digital in }
   BD_PCL723    =  AAC Or $20;     {  PCL-723 24-bit Digital in }
   BD_PCL818L   =  AAC Or $21;     {  PCL-818L  }
   BD_PCL818HG  =  AAC Or $22;     {  PCL-818HG }
   BD_PCL1800   =  AAC Or $23;     {  PCL-1800 }
   BD_PAD71A    =  AAC Or $24;     {  PCIA-71A }
   BD_PAD71B    =  AAC Or $25;     {  PCIA-71B }
   BD_PCR420    =  AAC Or $26;     {  PCR-420  }
   BD_PCL731    =  AAC Or $27;     {  PCL-731 48-bit Digital I/O card  }
   BD_PCL730    =  AAC Or $28;     {  PCL-730 board }
   BD_PCL813    =  AAC Or $29;     {  PCL-813 32-channel A/D card  }
   BD_PCL813B   =  AAC Or $2a;     {  PCL-813B 32-channel A/D card }
   BD_PCL818HD  =  AAC Or $2b;     {  PCL-818HD }
   BD_PCL725    =  AAC Or $2c;     {  PCL-725 digital I/O card }
   BD_PCL732    =  AAC Or $2d;     {  PCL-732 high speed DIO card }
   BD_AD4018    =  AAC Or $2e;     {  ADAM 4018 Module }
   BD_814_TC_1  =  AAC Or $2f;     {  PCL-816/814B 16 bit TC module }
   BD_PAD71C    =  AAC Or $30;     {  PCIA-71C }
   BD_AD4024    =  AAC Or $31;     {  ADAM 4024 }
   BD_AD5017    =  AAC Or $32;     {  ADAM 5017 }
   BD_AD5018    =  AAC Or $33;     {  ADAM 5018 }
   BD_AD5024    =  AAC Or $34;     {  ADAM 5024 }
   BD_AD5051    =  AAC Or $35;     {  ADAM 5051 }
   BD_AD5060    =  AAC Or $36;     {  ADAM 5060 }
   BD_PCM3718   =  AAC Or $37;     {  PCM-3718  }
   BD_PCM3724   =  AAC Or $38;     {  PCM-3724  }
   BD_MIC2718   =  AAC Or $39;     {  MIC-2718  }
   BD_MIC2728   =  AAC Or $3a;     {  MIC-2728  }
   BD_MIC2730   =  AAC Or $3b;     {  MIC-2730  }
   BD_MIC2732   =  AAC Or $3c;     {  MIC-2732  }
   BD_MIC2750   =  AAC Or $3d;     {  MIC-2750  }
   BD_MIC2752   =  AAC Or $3e;     {  MIC-2752  }
   BD_PCL733    =  AAC Or $3f;     {  PCL-733   }
   BD_PCL734    =  AAC Or $40;     {  PCL-734   }
   BD_PCL735    =  AAC Or $41;     {  PCL-735   }
   BD_AD4018M   =  AAC Or $42;     {  ADAM 4018M Module }
   BD_AD4080    =  AAC Or $43;     {  ADAM 4080 Module  }
   BD_PCL833    =  AAC Or $44;     {  PCL-833   }
   BD_PCA6157   =  AAC Or $45;     {  PCA-6157  }
   BD_PCA6149   =  AAC Or $46;     {  PCA-6149  }
   BD_PCA6147   =  AAC Or $47;     {  PCA-6147  }
   BD_PCA6137   =  AAC Or $48;     {  PCA-6137  }
   BD_PCA6145   =  AAC Or $49;     {  PCA-6145  }
   BD_PCA6144   =  AAC Or $4a;     {  PCA-6144  }
   BD_PCA6143   =  AAC Or $4b;     {  PCA-6143  }
   BD_PCA6134   =  AAC Or $4c;     {  PCA-6134  }
   BD_AD5056    =  AAC Or $4d;     {  ADAM 5056 }
   BD_DN5017    =  AAC Or $4e;     {  ADAM 5017 }
   BD_DN5018    =  AAC Or $4f;     {  ADAM 5018 }
   BD_DN5024    =  AAC Or $50;     {  ADAM 5024 }
   BD_DN5051    =  AAC Or $51;     {  ADAM 5051 }
   BD_DN5056    =  AAC Or $52;     {  ADAM 5056 }
   BD_DN5060    =  AAC Or $53;     {  ADAM 5060 }
   BD_PCL836    =  AAC Or $54;     {  PCL-836   }
   BD_PCL841    =  AAC Or $55;     {  PCL-841   }
   BD_DN5050    =  AAC Or $56;     {  ADAM 5050 }
   BD_DN5052    =  AAC Or $57;     {  ADAM 5052 }
   BD_AD5050    =  AAC Or $58;     { ADAM 5050 for RS-485 }
   BD_AD5052    =  AAC Or $59;     { ADAM 5052 for RS-485 }
   BD_PCM3730   =  AAC Or $5a;     { PCM-3730 }
   BD_AD4011D   =  AAC Or $5b;     { ADAM 4011D }
   BD_AD4016    =  AAC Or $5c;     { ADAM 4016 }
   BD_AD4053    =  AAC Or $5d;     { ADAM 4053 }
   BD_PCI1750   =  AAC Or $5e;     { PCI-1750 }
   BD_PCI1751   =  AAC Or $5f;     { PCI-1751 }
   BD_PCI1710   =  AAC Or $60;     { PCI-1710 }
   BD_PCI1712   =  AAC Or $61;     { PCI-1712 }
   BD_AD5068    =  AAC Or $5e;     {  ADAM 5068	}
   BD_AD5013    =  AAC Or $5f;     {  ADAM 5013	}
   BD_AD5017H   =  AAC Or $60;     {  ADAM 5017H(unavailable)	}
   BD_AD5080    =  AAC Or $61;     {  ADAM 5080(unavailable)	}

   BD_MICRODAC =  GRAYHILL Or $1; {  Grayhill MicroDAC Board ID }
   BD_GIA10    =  KGS Or $01;     {  KGS GIA-10 module Board ID }

{ ************************************************************************ }
{   Define Expansion Board ID.                                             }
{ ************************************************************************ }
   AAC_EXP     =  AAC Or $00000100;  { Advantech expansion bits }

{ define Advantech expansion board ID.
   BD_PCLD780   = $00000000;         {  PCLD-780  }
   BD_PCLD789   = AAC_EXP Or $0;     {  PCLD-789  }
   BD_PCLD779   = AAC_EXP Or $1;     {  PCLD-779  }
   BD_PCLD787   = AAC_EXP Or $2;     {  PCLD-787  }
   BD_PCLD8115  = AAC_EXP Or $3;     {  PCLD-8115 }
   BD_PCLD770   = AAC_EXP Or $4;     {  PCLD-770  }
   BD_PCLD788   = AAC_EXP Or $5;     {  PCLD-788  }

{ ************************************************************************ }
{   Define subsection identifier                                           }
{ ************************************************************************ }
  DAS_AISECTION     = $1;        {  A/D subsection                }
  DAS_AOSECTION     = $2;        {  D/A sbusection                }
  DAS_DISECTION     = $3;        {  Digital input subsection      }
  DAS_DOSECTION     = $4;        {  Digital output sbusection     }
  DAS_TEMPSECTION   = $5;        {  thermocouple section          }
  DAS_ECSECTION     = $6;        {  Event count subsection        }
  DAS_FMSECTION     = $7;        {  frequency measurement section }
  DAS_POSECTION     = $8;        {  pulse output section          }
  DAS_ALSECTION     = $9;        {  alarm section                 }
  MT_AISECTION      = $0a;       {  monitoring A/D subsection     }
  MT_DISECTION      = $0b;       {  monitoring D/I subsection     }

{ ************************************************************************ }
{   Define Transfer Mode                                                   }
{ ************************************************************************ }
  POLLED_MODE       =  $0;        {  software transfer  }
  DMA_MODE          =  $1;        {  DMA transfer       }
  INTERRUPT_MODE    =  $2;        {  Interrupt transfer }

{ ************************************************************************ }
{   Define Acquisition Mode                                                }
{ ************************************************************************ }
  FREE_RUN          =  0;
  PRE_TRIG          =  1;
  POST_TRIG         =  2;
  POSITION_TRIG     =  3;

{ ************************************************************************ }
{   Define Comparator's Condition                                          }
{ ************************************************************************ }
  NOCONDITION       =  0;
  LESS              =  1;
  BETWEEN           =  2;
  GREATER           =  3;
  OUTSIDE           =  4;

{ ************************************************************************ }
{   Define Status Code                                                     }
{ ************************************************************************ }
  SUCCESS               =  0;
  DrvErrorCode          =  1;
  KeErrorCode           =  100;
  DnetErrorCode         =  200;
  MemoryAllocateFailed  =  DrvErrorCode + 0;
  ConfigDataLost        =  DrvErrorCode + 1;
  InvalidDeviceHandle   =  DrvErrorCode + 2;
  AIConversionFailed    =  DrvErrorCode + 3;
  AIScaleFailed         =  DrvErrorCode + 4;
  SectionNotSupported   =  DrvErrorCode + 5;
  InvalidChannel        =  DrvErrorCode + 6;
  InvalidGain           =  DrvErrorCode + 7;
  DataNotReady          =  DrvErrorCode + 8;
  InvalidInputParam     =  DrvErrorCode + 9;
  NoExpansionBoardConfig=  DrvErrorCode + 10;
  InvalidAnalogOutValue =  DrvErrorCode + 11;
  ConfigIoPortFailed    =  DrvErrorCode + 12;
  CommOpenFailed        =  DrvErrorCode + 13;
  CommTransmitFailed    =  DrvErrorCode + 14;
  CommReadFailed        =  DrvErrorCode + 15;
  CommReceiveFailed     =  DrvErrorCode + 16;
  CommConfigFailed      =  DrvErrorCode + 17;
  CommChecksumError     =  DrvErrorCode + 18;
  InitError             =  DrvErrorCode + 19;
  DMABufAllocFailed     =  DrvErrorCode + 20;
  IllegalSpeed          =  DrvErrorCode + 21;
  ChanConflict          =  DrvErrorCode + 22;
  BoardIDNotSupported   =  DrvErrorCode + 23;
  FreqMeasurementFailed =  DrvErrorCode + 24;
  CreateFileFailed      =  DrvErrorCode + 25;
  FunctionNotSupported  =  DrvErrorCode + 26;
  LoadLibraryFailed     =  DrvErrorCode + 27;
  GetProcAddressFailed  =  DrvErrorCode + 28;
  InvalidDriverHandle   =  DrvErrorCode + 29;
  InvalidModuleType     =  DrvErrorCode + 30;
  InvalidInputRange     =  DrvErrorCode + 31;
  InvalidWindowsHandle  =  DrvErrorCode + 32;
  InvalidCountNumber    =  DrvErrorCode + 33;
  InvalidInterruptCount =  DrvErrorCode + 34;
  InvalidEventCount     =  DrvErrorCode + 35;
  OpenEventFailed       =  DrvErrorCode + 36;
  InterruptProcessFailed=  DrvErrorCode + 37;
  InvalidDOSetting      =  DrvErrorCode + 38;
  InvalidEventType      =  DrvErrorCode + 39;
  EventTimeOut          =  DrvErrorCode + 40;
  InvalidDmaChannel     =  DrvErrorCode + 41;

  KeInvalidHandleValue =  KeErrorCode + 0;
  KeFileNotFound       =  KeErrorCode + 1;
  KeInvalidHandle      =  KeErrorCode + 2;
  KeTooManyCmds        =  KeErrorCode + 3;
  KeInvalidParameter   =  KeErrorCode + 4;
  KeNoAccess           =  KeErrorCode + 5;
  KeUnsuccessful         = KeErrorCode + 6;
  KeConInterruptFailure  = KeErrorCode + 7;
  KeCreateNoteFailure    = KeErrorCode + 8;
  KeInsufficientResources= KeErrorCode + 9;
  KeHalGetAdapterFailure = KeErrorCode +10;
  KeOpenEventFailure     = KeErrorCode +11;
  KeAllocCommBufFailure  = KeErrorCode +12;
  KeAllocMdlFailure      = KeErrorCode +13;
  KeBufferSizeTooSmall   = KeErrorCode +14;

  DNInitFailed          =   DnetErrorCode + 1;
  DNSendMsgFailed       =   DnetErrorCode + 2;
  DNRunOutOfMsgID       =   DnetErrorCode + 3;
  DNInvalidInputParam   =   DnetErrorCode + 4;
  DNErrorResponse       =   DnetErrorCode + 5;
  DNNoResponse          =   DnetErrorCode + 6;
  DNBusyOnNetwork       =   DnetErrorCode + 7;
  DNUnknownResponse     =   DnetErrorCode + 8;
  DNNotEnoughBuffer     =   DnetErrorCode + 9;
  DNFragResponseError   =   DnetErrorCode + 10;
  DNTooMuchDataAck      =   DnetErrorCode + 11;
  DNFragRequestError    =   DnetErrorCode + 12;
  DNEnableEventError      = DnetErrorCode + 13;
  DNCreateOrOpenEventError= DnetErrorCode + 14;
  DNIORequestError        = DnetErrorCode + 15;
  DNGetEventNameError     = DnetErrorCode + 16;
  DNTimeOutError          = DnetErrorCode + 17;
  DNOpenFailed            = DnetErrorCode + 18;
  DNCloseFailed           = DnetErrorCode + 19;
  DNResetFailed           = DnetErrorCode + 20;

{  define Windows message     }
  WM_USER               =  $400;
{  define user window message }
  WM_ATODNOTIFY         =  WM_USER+200;
  WM_DTOANOTIFY         =  WM_USER+201;
  WM_DIGINNOTIFY        =  WM_USER+202;
  WM_DIGOUTNOTIFY       =  WM_USER+203;
  WM_MTNOTIFY           =  WM_USER+204;
  WM_CANTRANSMITCOMPLETE=  WM_USER+205;
  WM_CANMESSAGE         =  WM_USER+206;
  WM_CANERROR           =  WM_USER+207;

{  define the wParam in user window message }
  AD_NONE               =  0; { AD Section }
  AD_TERMINATE          =  1;
  AD_INT                =  2;
  AD_BUFFERCHANGE       =  3;
  AD_OVERRUN            =  4;
  AD_WATCHDOGACT        =  5;
  AD_TIMEOUT            =  6;
  DA_TERMINATE          =  0; {  DA Section }
  DA_DMATC              =  1;
  DA_INT                =  2;
  DA_BUFFERCHANGE       =  3;
  DA_OVERRUN            =  4;
  DI_TERMINATE          =  0; {  DI Section }
  DI_DMATC              =  1;
  DI_INT                =  2;
  DI_BUFFERCHANGE       =  3;
  DI_OVERRUN            =  4;
  DI_WATCHDOGACT        =  5;
  DO_TERMINATE          =  0; {  DO Section }
  DO_DMATC              =  1;
  DO_INT                =  2;
  DO_BUFFERCHANGE       =  3;
  DO_OVERRUN            =  4;
  MT_ATOD               =  0; {  MT Section }
  MT_DIGIN              =  1;

  CAN_TRANSFER          =  0; { CAN Section }
  CAN_RECEIVE           =  1;
  CAN_ERROR             =  2;

{ ************************************************************************ }
{   define thermocopule type J, K, S, T, B, R, E                           }
{ ************************************************************************ }
  BTC = 4;
  ETC = 6;
  JTC = 0;
  KTC = 1;
  RTC = 5;
  STC = 2;
  TTC = 3;

{ ************************************************************************ }
{   define  temperature scale                                              }
{ ************************************************************************ }
  C = 0;      { Celsius    }
  F = 1;      { Fahrenheit }
  R = 2;      {  Rankine   }
  K = 3;      {  Kelvin    }


{ ************************************************************************ }
{   define service type for COMEscape()                                    }
{ ************************************************************************ }
  EscapeFlushInput      = 1;
  EscapeFlushOutput     = 2;
  EscapeSetBreak        = 3;
  EscapeClearBreak      = 4;


{ ************************************************************************ }
{   define  gate mode                                                      }
{ ************************************************************************ }
  GATE_DISABLED     = 0;      {  no gating         }
  GATE_HIGHLEVEL    = 1;      {  active high level }
  GATE_LOWLEVEL     = 2;      {  active low level  }
  GATE_HIGHEDGE     = 3;      {  active high edge  }
  GATE_LOWEDGE      = 4;      {  active low edge   }


{ ************************************************************************ }
{   define input mode for PCL-833                                          }
{ ************************************************************************ }
  DISABLE           = 0;      {  disable mode         }
  ABPHASEX1         = 1;      {  Quadrature input X1  }
  ABPHASEX2         = 2;      {  Quadrature input X2  }
  ABPHASEX4         = 3;      {  Quadrature input X4  }
  TWOPULSEIN        = 4;      {  2 pulse input        }
  ONEPULSEIN        = 5;      {  1 pulse input        }

{ ************************************************************************ }
{   define latch source for PCL-833                                        }
{ ************************************************************************ }
  SWLATCH           = 0;      {  S/W read latch data }
  INDEXINLATCH      = 1;      {  Index-in latch data }
  DI0LATCH          = 2;      {  DI0 latch data      }
  DI1LATCH          = 3;      {  DI1 latch data      }
  TIMERLATCH        = 4;      {  Timer latch data    }

{ ************************************************************************ }
{   define timer base mode for PCL-833                                     }
{ ************************************************************************ }
  TPOINT1MS   = 0;      {     0.1 ms timer base }
  T1MS        = 1;      {     1   ms timer base }
  T10MS       = 2;      {    10   ms timer base }
  T100MS      = 3;      {   100   ms timer base }
  T1000MS     = 4;      {  1000   ms timer base }

{ ************************************************************************ }
{   define clock source for PCL-833                                        }
{ ************************************************************************ }
  SYS8MHZ     =    0;      {  8 MHZ system clock }
  SYS4MHZ     =    1;      {  4 MHZ system clock }
  SYS2MHZ     =    2;      {  2 MHZ system clock }

{ ************************************************************************ }
{   define cascade mode for PCL-833                                        }
{ ************************************************************************ }
  NOCASCADE   =       0;      {  24-bit(no cascade) }
  CASCADE     =       1;      {  48-bit(CH1, CH2 cascade) }


{ ************************************************************************ }
{   define event type for interrupt and DMA transfer                       }
{ ************************************************************************ }
  ADS_EVT_INTERRUPT  =  $01;   { interrupt }
  ADS_EVT_BUFCHANGE  =  $02;   { buffer change }
  ADS_EVT_TERMINATED =  $04;   { termination }
  ADS_EVT_OVERRUN    =  $08;   { overrun }
  ADS_EVT_WATCHDOG   =  $10;   { watchdog actived }
  ADS_EVT_CHGSTATE   =  $20;   { change state event }
  ADS_EVT_ALARM      =  $40;   { alarm event }
  ADS_EVT_PORT0      =  $80;   { port 0 event }
  ADS_EVT_PORT1      = $100;   { port 1 event }

{ ************************************************************************ }
{    define event name by device number                                    }
{ ************************************************************************ }
  ADS_EVT_INTERRUPT_NAME  = 'ADS_EVT_INTERRUPT';
  ADS_EVT_BUFCHANGE_NAME  = 'ADS_EVT_BUFCHANGE';
  ADS_EVT_TERMINATED_NAME = 'ADS_EVT_TERMINATED';
  ADS_EVT_OVERRUN_NAME    = 'ADS_EVT_OVERRUN';
  ADS_EVT_WATCHDOG_NAME   = 'ADS_EVT_WATCHDOG';
  ADS_EVT_CHGSTATE_NAME   = 'ADS_EVT_CHGSTATE';
  ADS_EVT_ALARM_NAME      = 'ADS_EVT_ALARM';


{ ************************************************************************ }
{    define FIFO size                                                      }
{ ************************************************************************ }
  FIFO_SIZE         =  512;     { 1K FIFO size (512* 2byte/each data) }

{ ************************************************************************ }
{   Function ID Definition                                                 }
{ ************************************************************************ }
  FID_DeviceOpen              =   0;
  FID_DeviceClose             =   1;
  FID_DeviceGetFeatures       =   2;
  FID_AIConfig                =   3;
  FID_AIGetConfig             =   4;
  FID_AIBinaryIn              =   5;
  FID_AIScale                 =   6;
  FID_AIVoltageIn             =   7;
  FID_AIVoltageInExp          =   8;
  FID_MAIConfig               =   9;
  FID_MAIBinaryIn             =  10;
  FID_MAIVoltageIn            =  11;
  FID_MAIVoltageInExp         =  12;
  FID_TCMuxRead               =  13;
  FID_AOConfig                =  14;
  FID_AOBinaryOut             =  15;
  FID_AOVoltageOut            =  16;
  FID_AOScale                 =  17;
  FID_DioSetPortMode          =  18;
  FID_DioGetConfig            =  19;
  FID_DioReadPortByte         =  20;
  FID_DioWritePortByte        =  21;
  FID_DioReadBit              =  22;
  FID_DioWriteBit             =  23;
  FID_DioGetCurrentDOByte     =  24;
  FID_DioGetCurrentDOBit      =  25;
  FID_WritePortByte           =  26;
  FID_WritePortWord           =  27;
  FID_ReadPortByte            =  28;
  FID_ReadPortWord            =  29;
  FID_CounterEventStart       =  30;
  FID_CounterEventRead        =  31;
  FID_CounterFreqStart        =  32;
  FID_CounterFreqRead         =  33;
  FID_CounterPulseStart       =  34;
  FID_CounterReset            =  35;
  FID_QCounterConfig          =  36;
  FID_QCounterConfigSys       =  37;
  FID_QCounterStart           =  38;
  FID_QCounterRead            =  39;
  FID_AlarmConfig             =  40;
  FID_AlarmEnable             =  41;
  FID_AlarmCheck              =  42;
  FID_AlarmReset              =  43;
  FID_COMOpen                 =  44;
  FID_COMConfig               =  45;
  FID_COMClose                =  46;
  FID_COMRead                 =  47;
  FID_COMWrite232             =  48;
  FID_COMWrite485             =  49;
  FID_COMWrite85              =  50;
  FID_COMInit                 =  51;
  FID_COMLock                 =  52;
  FID_COMUnlock               =  53;
  FID_WDTEnable               =  54;
  FID_WDTRefresh              =  55;
  FID_WDTReset                =  56;
  FID_FAIIntStart             =  57;
  FID_FAIIntScanStart         =  58;
  FID_FAIDmaStart             =  59;
  FID_FAIDmaScanStart         =  60;
  FID_FAIDualDmaStart         =  61;
  FID_FAIDualDmaScanStart     =  62;
  FID_FAICheck                =  63;
  FID_FAITransfer             =  64;
  FID_FAIStop                 =  65;
  FID_FAIWatchdogConfig       =  66;
  FID_FAIIntWatchdogStart     =  67;
  FID_FAIDmaWatchdogStart     =  68;
  FID_FAIWatchdogCheck        =  69;
  FID_FAOIntStart             =  70;
  FID_FAODmaStart             =  71;
  FID_FAOScale                =  72;
  FID_FAOLoad                 =  73;
  FID_FAOCheck                =  74;
  FID_FAOStop                 =  75;
  FID_ClearOverrun            =  76;
  FID_EnableEvent             =  77;
  FID_CheckEvent              =  78;
  FID_AllocateDMABuffer       =  79;
  FID_FreeDMABuffer           =  80;
  FID_EnableCANEvent          =  81;
  FID_GetCANEventData         =  82;
Type
{ ************************************************************************ }
{   define gain listing                                                    }
{ ************************************************************************ }
 GAINLIST = Record
  usGainCde   : Smallint;
  fMaxGainVal : Single;
  fMinGainVal : Single;
  szGainStr   : array [0..15] of char;
 End;

{ ************************************************************************ }
{   Define hardware board(device) features.                                }
{                                                                          }
{   Note: definition for dwPermutaion member                               }
{                                                                          }
{          Bit 0: Software AI                                              }
{          Bit 1: DMA AI                                                   }
{          Bit 2: Interrupt AI                                             }
{          Bit 3: Condition AI                                             }
{          Bit 4: Software AO                                              }
{          Bit 5: DMA AO                                                   }
{          Bit 6: Interrupt AO                                             }
{          Bit 7: Condition AO                                             }
{          Bit 8: Software DI                                              }
{          Bit 9: DMA DI                                                   }
{          Bit 10: Interrupt DI                                            }
{          Bit 11: Condition DI                                            }
{          Bit 12: Software DO                                             }
{          Bit 13: DMA DO                                                  }
{          Bit 14: Interrupt DO                                            }
{          Bit 15: Condition DO                                            }
{          Bit 16: High Gain                                               }
{          Bit 17: Auto Channel Scan                                       }
{          Bit 18: Pacer Trigger                                           }
{          Bit 19: External Trigger                                        }
{          Bit 20: Down Counter                                            }
{          Bit 21: Dual DMA                                                }
{          Bit 22: Monitoring                                              }
{          Bit 23: QCounter                                                }
{                                                                          }
{ ************************************************************************ }
 DEVFEATURES= Record
    szDriverVer : array[0..7] of char;                      { device driver version }
    szDriverName: array[0..MAX_DRIVER_NAME_LEN-1] of char;  { device driver name    }
    dwBoardID      : Longint;    { board ID                              }
    usMaxAIDiffChl : Smallint;    { Max. number of differential channel   }
    usMaxAISiglChl : Smallint;    { Max. number of single-end channel     }
    usMaxAOChl     : Smallint;    { Max. number of D/A channel            }
    usMaxDOChl     : Smallint;    { Max. number of digital out channel    }
    usMaxDIChl     : Smallint;    { Max. number of digital input channel  }
    usDIOPort      : Smallint;    { specifies if programmable or not      }
    usMaxTimerChl  : Smallint;    { Max. number of Counter/Timer channel  }
    usMaxAlarmChl  : Smallint;    { Max number of  alram channel          }
    usNumADBit     : Smallint;    { number of bits for A/D converter      }
    usNumADByte    : Smallint;    { A/D channel width in bytes.           }
    usNumDABit     : Smallint;    { number of bits for D/A converter.     }
    usNumDAByte    : Smallint;    { D/A channel width in bytes.           }
    usNumGain      : Smallint;    { Max. number of gain code              }
    glGainList    : array[0..15] of GAINLIST;   { Gain listing }
    dwPermutation : array [0..3] of Longint;    { Permutation }
 End;

{ ************************************************************************ }
{    AOSET Definition                                                      }
{ ************************************************************************ }
 AOSET = Record
    usAOSource : Smallint;     { 0-internal, 1-external }
    fAOMaxVol  : Single;      { maximum output voltage }
    fAOMinVol  : Single;      { minimum output voltage }
 End;

{ ************************************************************************ }
{    DaughterSet Definition                                                }
{ ************************************************************************ }
 DAUGHTERSET = Record
    dwBoardID : Longint;              { expansion board ID }
    usNum     : Smallint;              { available expansion channels }
    fGain     : Single;               { gain for expansion channel }
    usCards   : Smallint;              { number of expansion cards }
 End;

{ ************************************************************************ }
{    Analog Input Configuration Definition                                 }
{ ************************************************************************ }
 DEVCONFIG_AI = Record
    dwBoardID     : Longint;     { board ID code                         }
    usChanConfig  : Smallint;     { 0-single ended, 1-differential        }
    usGainCtrMode : Smallint;     { 1-by jumper, 0-programmable           }
    usPolarity    : Smallint;     { 0-bipolar, 1-unipolar                 }
    usDasGain     : Smallint;     { not used if GainCtrMode = 1           }
    usNumExpChan  : Smallint;     { DAS channels attached expansion board }
    usCjcChannel  : Smallint;     { cold junction channel                 }
    Daughter: array [0..MAX_DAUGHTER_NUM-1] of DAUGHTERSET ;  { expansion board settings }
 End;

{ ************************************************************************ }
{    DEVCONFIG_COM Definition                                              }
{ ************************************************************************ }
 DEVCONFIG_COM = Record
    usCommPort    : Smallint;                { serial port  }
    dwBaudRate    : Longint;                 { baud rate    }
    usParity      : Smallint;                { parity check }
    usDataBits    : Smallint;                { data bits    }
    usStopBits    : Smallint;                { stop bits    }
    usTxMode      : Smallint;                { transmission mode }
    usPortAddress : Smallint;                { communication port address }
 End;

{ ************************************************************************ }
{    TRIGLEVEL Definition                                                  }
{ ************************************************************************ }
 TRIGLEVEL = Record
  fLow  : Single;
  fHigh : Single;
 End;


 PT_DEVLIST = Record
    dwDeviceNum      : Longint;
    szDeviceName     : array [0..49] of char;
    nNumOfSubdevices : Smallint;
 End;

 PT_DeviceGetFeatures  = Record
    buffer : Pointer;        { LPDEVFEATURES }
    size   : Smallint;
 End;

 PT_AIConfig  = Record
    DasChan : Smallint;
    DasGain : Smallint;
 End;

 PT_AIGetConfig  = Record
    buffer : Pointer;        { LPDEVCONFIG_AI }
    size   : Smallint;
 End;

 PT_AIBinaryIn  = Record
    chan     : Smallint;
    TrigMode : Smallint;
    reading  : Pointer;      { USHORT far *reading }
 End;

 PT_AIScale  = Record
    reading  : Smallint;
    MaxVolt  : Single;
    MaxCount : Smallint;
    offset   : Smallint;
    voltage  : ^Single;      { Float far *Voltage }
 End;

 PT_AIVoltageIn  = Record
    chan : Smallint;
    gain : Smallint;
    TrigMode : Smallint;
    voltage  : ^Single;      { Float far *Voltage }
 End;

 PT_AIVoltageInExp  = Record
    DasChan : Smallint;
    DasGain : Smallint;
    ExpChan : Smallint;
    voltage : ^Single;      { Float far *Voltage }
 End;

 PT_MAIConfig  = Record
    NumChan   : Smallint;
    StartChan : Smallint;
    GainArray : ^Smallint;  { USHORT far *Reading }
 End;

 PT_MAIBinaryIn  = Record
    NumChan      : Smallint;
    StartChan    : Smallint;
    TrigMode     : Smallint;
    ReadingArray : ^Single; { USHORT far *Reading }
 End;

 PT_MAIVoltageIn  = Record
    NumChan   : Smallint;
    StartChan : Smallint;
    GainArray : ^Smallint;  { Float far *VoltageArray }
    TrigMode  : Smallint;
    VoltageArray : ^Single;  { Float far *VoltageArray }
 End;

 PT_MAIVoltageInExp  = Record
    NumChan : Smallint;
    DasChanArray : ^Smallint;  { USHORT far *DasChanArray }
    DasGainArray : ^Smallint;  { USHORT far *DasGainArray }
    ExpChanArray : ^Smallint;  { USHORT far *ExpChanArray }
    VoltageArray : ^Single;    { Float  far *VoltageArray }
 End;

 PT_TCMuxRead  = Record
    DasChan   : Smallint;
    DasGain   : Smallint;
    ExpChan   : Smallint;
    TCType    : Smallint;
    TempScale : Smallint;
    temp      : ^Single;       { FLOAT far *temp }
 End;

 PT_AOConfig  = Record
    chan : Smallint;
    RefSrc : Smallint;
    MaxValue : Single;
    MinValue : Single;
 End;

 PT_AOBinaryOut  = Record
    chan : Smallint;
    BinData : Smallint;
 End;

 PT_AOVoltageOut  = Record
    chan : Smallint;
    OutputValue : Single;
 End;

 PT_AOScale  = Record
    chan        : Smallint;
    OutputValue : Single;
    BinData     : ^Smallint;   { USHORT far *BinData }
 End;

 PT_DioSetPortMode  = Record
    port : Smallint;
    dir  : Smallint;
 End;

 PT_DioGetConfig  = Record
    PortArray : ^Smallint;     { SHORT far *PortArray }
    NumOfPorts : Smallint;
 End;

 PT_DioReadPortByte  = Record
    port : Smallint;
    value: ^Smallint;          { USHORT far *value }
 End;

 PT_DioWritePortByte  = Record
    port : Smallint;
    mask : Smallint;
    state : Smallint;
 End;

 PT_DioReadBit  = Record
    port  : Smallint;
    bit   : Smallint;
    state : ^Smallint;
 End;

 PT_DioWriteBit  = Record
    port  : Smallint;
    bit   : Smallint;
    state : Smallint;
 End;

 PT_DioGetCurrentDOByte  = Record
    port : Smallint;
    value: ^Smallint;    { USHORT far *state }
 End;

 PT_DioGetCurrentDOBit   = Record
    port  : Smallint;
    bit   : Smallint;
    state : ^Smallint;   { USHORT far *state }
 End;

 PT_WritePortByte  = Record
    port     : Smallint;
    ByteData : Smallint;
 End;

 PT_WritePortWord  = Record
    port     : Smallint;
    WordData : Smallint;
 End;

 PT_ReadPortByte   = Record
    port     : Smallint;
    ByteData : Longint;
 End;

 PT_ReadPortWord  = Record
    port     : Smallint;
    WordData : Longint;
 End;

 PT_CounterEventStart  = Record
    counter  : Smallint;
    GateMode : Smallint;
 End;

 PT_CounterEventRead  = Record
    counter  : Smallint;
    overflow : ^Smallint;       { USHORT far *overflow }
    count    : ^Longint;      { ULONG far *count }
 End;

 PT_CounterFreqStart  = Record
    counter    : Smallint;
    GatePeriod : Smallint;
    GateMode   : Smallint;
 End;

 PT_CounterFreqRead  = Record
    counter : Smallint;
    freq    : ^Single;       { FLOAT far *freq }
 End;

 PT_CounterPulseStart  = Record
    counter  : Smallint;
    period   : Single;
    UpCycle  : Single;
    GateMode : Smallint;
 End;

 PT_QCounterConfig  = Record
    counter       : Smallint;
    LatchSrc      : Smallint;
    LatchOverflow : Smallint;
    ResetOnLatch  : Smallint;
    ResetValue    : Smallint;
 End;

 PT_QCounterConfigSys  = Record
    SysClock    : Smallint;
    TimeBase    : Smallint;
    TimeDivider : Smallint;
    CascadeMode : Smallint;
 End;

 PT_QCounterStart  = Record
    counter   : Smallint;
    InputMode : Smallint;
 End;

 PT_QCounterRead   = Record
    counter  : Smallint;
    overflow : ^Smallint;      { USHORT far * }
    LoCount  : ^Longint;       { ULONG far * }
    HiCount  : ^Longint;       { ULONG far * }
 End;

 PT_AlarmConfig  = Record
    chan    : Smallint;
    LoLimit : Single;
    HiLimit : Single;
 End;

 PT_AlarmEnable  = Record
    chan      : Smallint;
    LatchMode : Smallint;
    enabled   : Smallint;
 End;

 PT_AlarmCheck   = Record
    chan    : Smallint;
    LoState : ^Smallint;       { USHORT far * }
    HiState : ^Smallint;       { USHORT far * }
 End;

 PT_WDTEnable  = Record
    message     : Smallint;
    Destination : Longint;     { HWND }
 End;

 PT_FAIIntStart = Record
    TrigSrc    : Smallint;
    SampleRate : Longint;
    chan       : Smallint;
    gain       : Smallint;
    buffer     : ^Smallint;
    count      : Longint;
    cyclic     : Smallint;
    IntrCount  : Smallint;
 End;

 PT_FAIIntScanStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    NumChans    : Smallint;
    StartChan   : Smallint;
    GainList    : ^Smallint;
    buffer      : ^Smallint;
    count       : Longint;
    cyclic      : Smallint;
    IntrCount   : Smallint;
 End;

 PT_FAIDmaStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    chan        : Smallint;
    gain        : Smallint;
    buffer      : Pointer;
    count       : Longint;
 End;

 PT_FAIDmaScanStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    NumChans    : Smallint;
    StartChan   : Smallint;
    GainList    : ^Smallint;
    buffer      : Pointer;
    count       : Longint;
 End;

 PT_FAIDualDmaStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    chan        : Smallint;
    gain        : Smallint;
    BufferA     : ^Smallint;
    BufferB     : ^Smallint;
    count       : Longint;
    cyclic      : Smallint;
 End;

 PT_FAIDualDmaScanStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    NumChans    : Smallint;
    StartChan   : Smallint;
    GainList    : ^Smallint;
    BufferA     : ^Smallint;
    BufferB     : ^Smallint;
    count       : Longint;
    cyclic      : Smallint;
 End;

 PT_FAITransfer = Record
    ActiveBuf   : Smallint;
    DataBuffer  : Pointer;
    DataType    : Smallint;
    start       : Longint;
    count       : Longint;
    overrun     : ^Smallint;
 End;

 PT_FAICheck = Record
    ActiveBuf  : ^Smallint;
    stopped    : ^Smallint;
    retrieved  : ^Longint;
    overrun    : ^Smallint;
    HalfReady  : ^Smallint;
 End;

 PT_FAIWatchdogConfig = Record
    TrigMode    : Smallint;
    NumChans    : Smallint;
    StartChan   : Smallint;
    GainList    : ^Smallint;
    CondList    : ^Smallint;
    LevelList   : ^TRIGLEVEL;
 End;

 PT_FAIIntWatchdogStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    buffer      : ^Smallint;
    count       : Longint;
    cyclic      : Smallint;
    IntrCount   : Smallint;
 End;

 PT_FAIDmaWatchdogStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    BufferA     : ^Smallint;
    BufferB     : ^Smallint;
    count       : Longint;
 End;

 PT_FAIWatchdogCheck = Record
    DataType   : Smallint;
    ActiveBuf  : ^Smallint;
    triggered  : ^Smallint;
    TrigChan   : ^Smallint;
    TrigIndex  : ^Longint;
    TrigData   : Pointer;
 End;

 PT_FAOIntStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    chan        : Smallint;
    buffer      : ^Longint;
    count       : Longint;
    cyclic      : Smallint;
 End;

 PT_FAODmaStart = Record
    TrigSrc     : Smallint;
    SampleRate  : Longint;
    chan        : Smallint;
    buffer      : ^Longint;
    count       : Longint;
 End;

 PT_FAOScale = Record
    chan        : Smallint;
    count       : Longint;
    VoltArray   : ^Single;
    BinArray    : ^Smallint;
 End;

 PT_FAOLoad  = Record
    ActiveBuf   : Smallint;
    DataBuffer  : ^Smallint;
    start       : Smallint;
    count       : Longint;
 End;

 PT_FAOCheck = Record
    ActiveBuf     : ^Smallint;
    stopped       : ^Smallint;
    CurrentCount  : ^Longint;
    overrun       : ^Smallint;
    HalfReady     : ^Smallint;
 End;

 PT_EnableEvent = Record
    EventType   : Smallint;
    Enabled     : Smallint;
    Count       : Smallint;
 End;

PT_CheckEvent = Record
    EventType    : ^Smallint;
    Milliseconds : LongInt;
End;

 PT_AllocateDMABuffer = Record
    CyclicMode      : Smallint;
    RequestBufSize  : Longint;
    ActualBufSize   : ^Longint;
    buffer          : ^Longint;
 End;

{ ************************************************************************ }
{    Function Declaration for ADSAPI32                                      }
{ ************************************************************************ }

Function DRV_DeviceGetNumOfList(Var NumOfDevices : Smallint) : Longint; stdcall;
Function DRV_DeviceGetList(Var DeviceList : PT_DEVLIST;
             MaxEntries : Smallint; Var OutEntries : Smallint) : Longint; stdcall;
Function DRV_DeviceGetSubList(DeviceNum : Longint;
             Var SubDevList : PT_DEVLIST; MaxEntries : Smallint;
             Var OutEntries : Smallint) : Longint; stdcall;
Function DRV_SelectDevice( hCaller : HWND; wGetModule : Smallint;
             Var lDeviceNum : Longint; Var szDescription : Char) : Longint; stdcall;
Function DRV_DeviceOpen(DeviceNum : Longint;
             Var DriverHandle : Longint) : Longint; stdcall;
Function DRV_DeviceClose(Var DriverHandle : Longint) : Longint; stdcall;
Function DRV_DeviceGetFeatures(DriverHandle : Longint;
              Var lpDeviceGetFeatures : PT_DeviceGetFeatures) : Longint; stdcall;
Function DRV_BoardTypeMapBoardName(BoardID : Longint; ExpName : Pointer) : Longint; stdcall;
Procedure DRV_GetErrorMessage(lError : Longint; lpszErrMsg : Pointer); stdcall;
Function DRV_AIConfig(DriverHandle : Longint;
             Var lpAIConfig : PT_AIConfig) : Longint; stdcall;
Function DRV_AIGetConfig(DriverHandle : Longint;
             Var lpAIGetConfig : PT_AIGetConfig) : Longint; stdcall;
Function DRV_AIBinaryIn(DriverHandle : Longint;
             Var lpAIBinaryIn : PT_AIBinaryIn) : Longint; stdcall;
Function DRV_AIScale(DriverHandle : Longint;
             Var lpAIScale : PT_AIScale) : Longint; stdcall;
Function DRV_AIVoltageIn(DriverHandle : Longint;
             Var lpAIVoltageIn : PT_AIVoltageIn) : Longint; stdcall;
Function DRV_AIVoltageInExp(DriverHandle : Longint;
             Var lpAIVoltageInExp : PT_AIVoltageInExp) : Longint; stdcall;
Function DRV_MAIConfig(DriverHandle : Longint;
             Var lpMAIConfig : PT_MAIConfig) : Longint; stdcall;
Function DRV_MAIBinaryIn(DriverHandle : Longint;
             Var lpMAIBinaryIn : PT_MAIBinaryIn) : Longint; stdcall;
Function DRV_MAIVoltageIn(DriverHandle : Longint;
             Var lpMAIVoltageIn : PT_MAIVoltageIn) : Longint; stdcall;
Function DRV_MAIVoltageInExp(DriverHandle : Longint;
             Var lpMAIVoltageInExp : PT_MAIVoltageInExp) : Longint; stdcall;
Function DRV_TCMuxRead(DriverHandle : Longint;
             Var lpTCMuxRead : PT_TCMuxRead) : Longint; stdcall;
Function DRV_AOConfig(DriverHandle : Longint;
             Var lpAOConfig : PT_AOConfig) : Longint; stdcall;
Function DRV_AOBinaryOut(DriverHandle : Longint;
             Var lpAOBinaryOut : PT_AOBinaryOut) : Longint; stdcall;
Function DRV_AOVoltageOut(DriverHandle : Longint;
             Var lpAOVoltageOut : PT_AOVoltageOut) : Longint; stdcall;
Function DRV_AOScale(DriverHandle : Longint;
             Var lpAOScale : PT_AOScale) : Longint; stdcall;
Function DRV_DioSetPortMode(DriverHandle : Longint;
             Var lpDioSetPortMode : PT_DioSetPortMode) : Longint; stdcall;
Function DRV_DioGetConfig(DriverHandle : Longint;
             Var lpDioGetConfig : PT_DioGetConfig) : Longint; stdcall;
Function DRV_DioReadPortByte(DriverHandle : Longint;
             Var lpDioReadPortByte : PT_DioReadPortByte) : Longint; stdcall;
Function DRV_DioWritePortByte(DriverHandle : Longint;
             Var lpDioWritePortByte : PT_DioWritePortByte) : Longint; stdcall;
Function DRV_DioReadBit(DriverHandle : Longint;
             Var lpDioReadBit : PT_DioReadBit) : Longint; stdcall;
Function DRV_DioWriteBit(DriverHandle : Longint;
             Var lpDioWriteBit : PT_DioWriteBit) : Longint; stdcall;
Function DRV_DioGetCurrentDOByte(DriverHandle : Longint;
             Var lpDioGetCurrentDOByte : PT_DioGetCurrentDOByte) : Longint; stdcall;
Function DRV_DioGetCurrentDOBit(DriverHandle : Longint;
             Var lpDioGetCurrentDOBit : PT_DioGetCurrentDOBit) : Longint; stdcall;
Function DRV_WritePortByte(DriverHandle : Longint;
             Var lpWritePortByte : PT_WritePortByte) : Longint; stdcall;
Function DRV_WritePortWord(DriverHandle : Longint;
             Var lpWritePortWord : PT_WritePortWord) : Longint; stdcall;
Function DRV_ReadPortByte(DriverHandle : Longint;
             Var lpReadPortByte : PT_ReadPortByte) : Longint; stdcall;
Function DRV_ReadPortWord(DriverHandle : Longint;
             Var lpReadPortWord : PT_ReadPortWord) : Longint; stdcall;
Function DRV_CounterEventStart(DriverHandle : Longint;
             Var lpCounterEventStart : PT_CounterEventStart) : Longint; stdcall;
Function DRV_CounterEventRead(DriverHandle : Longint;
             Var lpCounterEventRead : PT_CounterEventRead) : Longint; stdcall;
Function DRV_CounterFreqStart(DriverHandle : Longint;
             Var lpCounterFreqStart : PT_CounterFreqStart) : Longint; stdcall;
Function DRV_CounterFreqRead(DriverHandle : Longint;
             Var lpCounterFreqRead : PT_CounterFreqRead) : Longint; stdcall;
Function DRV_CounterPulseStart(DriverHandle : Longint;
             Var lpCounterPulseStart : PT_CounterPulseStart) : Longint; stdcall;
Function DRV_CounterReset(DriverHandle : Longint;
             counter : Smallint) : Longint; stdcall;
Function DRV_QCounterConfig(DriverHandle : Longint;
             Var lpQCounterConfig : PT_QCounterConfig) : Longint; stdcall;
Function DRV_QCounterConfigSys(DriverHandle : Longint;
             Var lpQCounterConfigSys : PT_QCounterConfigSys) : Longint; stdcall;
Function DRV_QCounterStart(DriverHandle : Longint;
             Var lpQCounterStart : PT_QCounterStart) : Longint; stdcall;
Function DRV_QCounterRead(DriverHandle : Longint;
             Var lpQCounterRead : PT_QCounterRead) : Longint; stdcall;
Function DRV_AlarmConfig(DriverHandle : Longint;
             Var lpAlarmConfig : PT_AlarmConfig) : Longint; stdcall;
Function DRV_AlarmEnable(DriverHandle : Longint;
             Var lpAlarmEnable : PT_AlarmEnable) : Longint; stdcall;
Function DRV_AlarmCheck(DriverHandle : Longint;
             Var lpAlarmCheck : PT_AlarmCheck) : Longint; stdcall;
Function DRV_AlarmReset(DriverHandle : Longint;
             Var chan : Smallint) : Longint; stdcall;
Function DRV_WDTEnable(DriverHandle : Longint;
             Var lpWDTEnable : PT_WDTEnable) : Longint; stdcall;
Function DRV_WDTRefresh(DriverHandle : Longint) : Longint; stdcall;
Function DRV_WDTReset(DriverHandle : Longint) : Longint; stdcall;

{ Direct I/O Functions List }
Function DRV_outp(DeviceNum : Longint; port : Word; ByteData : Word) : Longint; stdcall;
Function DRV_outpw(DeviceNum : Longint; port : Word; ByteData : Word) : Longint; stdcall;
Function DRV_inp(DeviceNum : Longint; port : Word; var ByteData : Word) : Longint; stdcall;
Function DRV_inpw(DeviceNum : Longint; port : Word; var ByteData : Word) : Longint; stdcall;

{ High speed function declaration }
Function DRV_FAIWatchdogConfig(DriverHandle : Longint;
                      Var lpFAIWatchdogConfig : PT_FAIWatchdogConfig) : Longint ; stdcall;
Function DRV_FAIIntStart(DriverHandle : Longint;
                      Var lpFAIIntStart : PT_FAIIntStart) : Longint ; stdcall;
Function DRV_FAIIntScanStart(DriverHandle : Longint;
                      Var lpFAIIntScanStart : PT_FAIIntScanStart) : Longint ; stdcall;
Function DRV_FAIDmaStart(DriverHandle : Longint;
                      Var lpFAIDmaStart : PT_FAIDmaStart) : Longint ; stdcall;
Function DRV_FAIDmaScanStart(DriverHandle : Longint;
                      Var lpFAIDmaScanStart : PT_FAIDmaScanStart) : Longint ; stdcall;
Function DRV_FAIDualDmaStart(DriverHandle : Longint;
                      Var lpFAIDualDmaStart : PT_FAIDualDmaStart) : Longint ; stdcall;
Function DRV_FAIDualDmaScanStart(DriverHandle : Longint;
                      Var lpFAIDualDmaScanStart : PT_FAIDualDmaScanStart) : Longint ; stdcall;
Function DRV_FAIIntWatchdogStart(DriverHandle : Longint;
                      Var lpFAIIntWatchdogStart : PT_FAIIntWatchdogStart) : Longint ; stdcall;
Function DRV_FAIDmaWatchdogStart(DriverHandle : Longint;
                      Var lpFAIDmaWatchdogStart : PT_FAIDmaWatchdogStart) : Longint ; stdcall;
Function DRV_FAICheck(DriverHandle : Longint;
                      Var lpFAICheck : PT_FAICheck) : Longint ; stdcall;
Function DRV_FAIWatchdogCheck(DriverHandle : Longint;
                      Var lpFAIWatchdogCheck : PT_FAIWatchdogCheck) : Longint ; stdcall;
Function DRV_FAITransfer(DriverHandle : Longint;
                      Var lpFAITransfer : PT_FAITransfer) : Longint ; stdcall;
Function DRV_FAIStop(DriverHandle : Longint) : Longint ; stdcall;
Function DRV_FAOIntStart(DriverHandle : Longint;
                      Var lpFAOIntStart : PT_FAOIntStart) : Longint ; stdcall;
Function DRV_FAODmaStart(DriverHandle : Longint;
                      Var lpFAODmaStart : PT_FAODmaStart) : Longint ; stdcall;
Function DRV_FAOScale(DriverHandle : Longint;
                      Var lpFAOScale : PT_FAOScale) : Longint ; stdcall;
Function DRV_FAOLoad(DriverHandle : Longint;
                      Var lpFAOLoad : PT_FAOLoad) : Longint ; stdcall;
Function DRV_FAOCheck(DriverHandle : Longint;
                      Var lpFAOCheck : PT_FAOCheck) : Longint ; stdcall;
Function DRV_FAOStop(DriverHandle : Longint) : Longint ; stdcall;
Function DRV_ClearOverrun(DriverHandle : Longint) : Longint ; stdcall;
Function DRV_EnableEvent(DriverHandle : Longint;
                      Var lpEnableEvent : PT_EnableEvent) : Longint ; stdcall;
Function DRV_CheckEvent(DriverHandle : Longint;
                      Var lpCheckEvent : PT_CheckEvent) : Longint ; stdcall;
Function DRV_AllocateDMABuffer(DriverHandle : Longint;
                      Var lpAllocateDMABuffer : PT_AllocateDMABuffer) : Longint ; stdcall;
Function DRV_FreeDMABuffer( DriverHandle : longint;
                      buffer : Pointer) : Longint; stdcall;

{ ************************************************************************ }
{ CAN bus function declaration                                             }
{ ************************************************************************ }
Function CANPortOpen( DevNum: Word; var Port, HostID: Word): Longint; stdcall;
Function CANPortClose( Port: Word ): Longint; stdcall;
Function CANInit( Port: Word; BTR0, BTR1: Word; Mask: Byte ): Longint; stdcall;
Function CANReset( Port: Word): Longint; stdcall;
Function CANInpb( Port: Word; Offset: Word; var Data: Byte ): Longint; stdcall;
Function CANOutpb( Port: Word; Offset: Word; Value: Byte ): Longint; stdcall;
Function CANSetBaud( Port: Word; BTR0, BTR1: Word ): Longint; stdcall;
Function CANSetAcp( Port: Word; Acp, Mask: Word ): Longint; stdcall;
Function CANSetOutCtrl( Port: Word; OutCtrl: Word ): Longint; stdcall;
Function CANSetNormal( Port: Word ): Longint; stdcall;
Function CANHwReset( Port: Word ): Longint; stdcall;
Function CANSendMsg( Port: Word; TxBuf: PChar; Wait: Boolean ): Longint; stdcall;
Function CANQueryMsg( Port: Word;var Ready: LongBool; RcvBuf: PChar ): Longint; stdcall;
Function CANWaitForMsg( Port: Word; RcvBuf: PChar; TimeValue: Longint ): Longint; stdcall;
Function CANQueryID( Port: Word;var Ready: LongBool; IDBuf: PChar ): Longint; stdcall;
Function CANWaitForID( Port: Word; IDBuf: PChar; TimeValue: Longint ): Longint; stdcall;
Function CANEnableMessaging( Port: Word; Type1: Word; Enabled: Boolean;
              AppWnd: THandle; RcvBuf: PChar ): Longint; stdcall;
Function CANGetEventName( Port: Word; RcvBuf: PChar ): Longint; stdcall;

{ ************************************************************************ }
{  DLL Function Declarations - ADSAPI32.DLL in windows dir                  }
{ ************************************************************************ }
implementation

Function DRV_DeviceGetNumOfList;    external 'adsapi32.dll';
Function DRV_DeviceGetList;         external 'adsapi32.dll';
Function DRV_DeviceGetSubList;      external 'adsapi32.dll';
Function DRV_SelectDevice;          external 'adsapi32.dll';
Function DRV_DeviceOpen;            external 'adsapi32.dll';
Function DRV_DeviceClose;           external 'adsapi32.dll';
Function DRV_DeviceGetFeatures;     external 'adsapi32.dll';
Function DRV_BoardTypeMapBoardName; external 'adsapi32.dll';
Procedure DRV_GetErrorMessage;      external 'adsapi32.dll';
Function DRV_AIConfig;              external 'adsapi32.dll';
Function DRV_AIGetConfig;           external 'adsapi32.dll';
Function DRV_AIBinaryIn;            external 'adsapi32.dll';
Function DRV_AIScale;               external 'adsapi32.dll';
Function DRV_AIVoltageIn;           external 'adsapi32.dll';
Function DRV_AIVoltageInExp;        external 'adsapi32.dll';
Function DRV_MAIConfig;             external 'adsapi32.dll';
Function DRV_MAIBinaryIn;           external 'adsapi32.dll';
Function DRV_MAIVoltageIn;          external 'adsapi32.dll';
Function DRV_MAIVoltageInExp;       external 'adsapi32.dll';
Function DRV_TCMuxRead;             external 'adsapi32.dll';
Function DRV_AOConfig;              external 'adsapi32.dll';
Function DRV_AOBinaryOut;           external 'adsapi32.dll';
Function DRV_AOVoltageOut;          external 'adsapi32.dll';
Function DRV_AOScale;               external 'adsapi32.dll';
Function DRV_DioSetPortMode;        external 'adsapi32.dll';
Function DRV_DioGetConfig;          external 'adsapi32.dll';
Function DRV_DioReadPortByte;       external 'adsapi32.dll';
Function DRV_DioWritePortByte;      external 'adsapi32.dll';
Function DRV_DioReadBit;            external 'adsapi32.dll';
Function DRV_DioWriteBit;           external 'adsapi32.dll';
Function DRV_DioGetCurrentDOByte;   external 'adsapi32.dll';
Function DRV_DioGetCurrentDOBit;    external 'adsapi32.dll';
Function DRV_WritePortByte;         external 'adsapi32.dll';
Function DRV_WritePortWord;         external 'adsapi32.dll';
Function DRV_ReadPortByte;          external 'adsapi32.dll';
Function DRV_ReadPortWord;          external 'adsapi32.dll';
Function DRV_CounterEventStart;     external 'adsapi32.dll';
Function DRV_CounterEventRead;      external 'adsapi32.dll';
Function DRV_CounterFreqStart;      external 'adsapi32.dll';
Function DRV_CounterFreqRead;       external 'adsapi32.dll';
Function DRV_CounterPulseStart;     external 'adsapi32.dll';
Function DRV_CounterReset;          external 'adsapi32.dll';
Function DRV_QCounterConfig;        external 'adsapi32.dll';
Function DRV_QCounterConfigSys;     external 'adsapi32.dll';
Function DRV_QCounterStart;         external 'adsapi32.dll';
Function DRV_QCounterRead;          external 'adsapi32.dll';
Function DRV_AlarmConfig;           external 'adsapi32.dll';
Function DRV_AlarmEnable;           external 'adsapi32.dll';
Function DRV_AlarmCheck;            external 'adsapi32.dll';
Function DRV_AlarmReset;            external 'adsapi32.dll';
Function DRV_WDTEnable;             external 'adsapi32.dll';
Function DRV_WDTRefresh;            external 'adsapi32.dll';
Function DRV_WDTReset;              external 'adsapi32.dll';
Function DRV_outp;                  external 'adsapi32.dll';
Function DRV_outpw;                 external 'adsapi32.dll';
Function DRV_inp;                   external 'adsapi32.dll';
Function DRV_inpw;                  external 'adsapi32.dll';
Function DRV_FAIWatchdogConfig;     external 'adsapi32.dll';
Function DRV_FAIIntStart;           external 'adsapi32.dll';
Function DRV_FAIIntScanStart;       external 'adsapi32.dll';
Function DRV_FAIDmaStart;           external 'adsapi32.dll';
Function DRV_FAIDmaScanStart;       external 'adsapi32.dll';
Function DRV_FAIDualDmaStart;       external 'adsapi32.dll';
Function DRV_FAIDualDmaScanStart;   external 'adsapi32.dll';
Function DRV_FAIIntWatchdogStart;   external 'adsapi32.dll';
Function DRV_FAIDmaWatchdogStart;   external 'adsapi32.dll';
Function DRV_FAICheck;              external 'adsapi32.dll';
Function DRV_FAIWatchdogCheck;      external 'adsapi32.dll';
Function DRV_FAITransfer;           external 'adsapi32.dll';
Function DRV_FAIStop;               external 'adsapi32.dll';
Function DRV_FAOIntStart;           external 'adsapi32.dll';
Function DRV_FAODmaStart;           external 'adsapi32.dll';
Function DRV_FAOScale;              external 'adsapi32.dll';
Function DRV_FAOLoad;               external 'adsapi32.dll';
Function DRV_FAOCheck;              external 'adsapi32.dll';
Function DRV_FAOStop;               external 'adsapi32.dll';
Function DRV_ClearOverrun;          external 'adsapi32.dll';
Function DRV_EnableEvent;           external 'adsapi32.dll';
Function DRV_CheckEvent;            external 'adsapi32.dll';
Function DRV_AllocateDMABuffer;     external 'adsapi32.dll';
Function DRV_FreeDMABuffer;         external 'adsapi32.dll';

{ ************************************************************************ }
{  DLL Function Declarations - ADS841.dll in windows dir                   }
{ ************************************************************************ }

Function CANPortOpen;           external 'ADS841.dll';
Function CANPortClose;          external 'ADS841.dll';
Function CANInit;               external 'ADS841.dll';
Function CANReset;              external 'ADS841.dll';
Function CANInpb;               external 'ADS841.dll';
Function CANOutpb;              external 'ADS841.dll';
Function CANSetBaud;            external 'ADS841.dll';
Function CANSetAcp;             external 'ADS841.dll';
Function CANSetOutCtrl;         external 'ADS841.dll';
Function CANSetNormal;          external 'ADS841.dll';
Function CANHwReset;            external 'ADS841.dll';
Function CANSendMsg;            external 'ADS841.dll';
Function CANQueryMsg;           external 'ADS841.dll';
Function CANWaitForMsg;         external 'ADS841.dll';
Function CANQueryID;            external 'ADS841.dll';
Function CANWaitForID;          external 'ADS841.dll';
Function CANEnableMessaging;    external 'ADS841.dll';
Function CANGetEventName;       external 'ADS841.dll';

End.
